aboutsummaryrefslogtreecommitdiff
path: root/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureResponseType.java
diff options
context:
space:
mode:
Diffstat (limited to 'moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureResponseType.java')
-rw-r--r--moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureResponseType.java79
1 files changed, 41 insertions, 38 deletions
diff --git a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureResponseType.java b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureResponseType.java
index 8911c42..4ff5ac7 100644
--- a/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureResponseType.java
+++ b/moaSig/moa-sig/src/generated/java/at/gv/egiz/moasig/VerifyCMSSignatureResponseType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.15 at 04:11:53 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:50 PM CET
//
@@ -10,83 +10,86 @@ package at.gv.egiz.moasig;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.JAXBElement;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlElementRef;
-import javax.xml.bind.annotation.XmlElementRefs;
-import javax.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.JAXBElement;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlElementRef;
+import jakarta.xml.bind.annotation.XmlElementRefs;
+import jakarta.xml.bind.annotation.XmlType;
/**
- * <p>Java class for VerifyCMSSignatureResponseType complex type.
+ * <p>Java-Klasse für VerifyCMSSignatureResponseType complex type.
*
- * <p>The following schema fragment specifies the expected content contained within this class.
+ * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
* <pre>
- * &lt;complexType name="VerifyCMSSignatureResponseType">
- * &lt;complexContent>
- * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- * &lt;sequence maxOccurs="unbounded">
- * &lt;element name="SignerInfo" type="{http://www.w3.org/2000/09/xmldsig#}KeyInfoType"/>
- * &lt;element name="SignatureCheck" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}CheckResultType"/>
- * &lt;element name="CertificateCheck" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}CheckResultType"/>
- * &lt;element name="FormCheckResult" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}FormResultType" maxOccurs="unbounded" minOccurs="0"/>
- * &lt;element name="ExtendedCertificateCheck" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}ExtendedCertificateCheckResultType" minOccurs="0"/>
- * &lt;/sequence>
- * &lt;/restriction>
- * &lt;/complexContent>
- * &lt;/complexType>
+ * &lt;complexType name="VerifyCMSSignatureResponseType"&gt;
+ * &lt;complexContent&gt;
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ * &lt;sequence maxOccurs="unbounded"&gt;
+ * &lt;element name="SignerInfo" type="{http://www.w3.org/2000/09/xmldsig#}KeyInfoType"/&gt;
+ * &lt;element name="SignatureAlgorithm" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
+ * &lt;element name="SignatureCheck" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}CheckResultType"/&gt;
+ * &lt;element name="CertificateCheck" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}CheckResultType"/&gt;
+ * &lt;element name="FormCheckResult" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}FormResultType" maxOccurs="unbounded" minOccurs="0"/&gt;
+ * &lt;element name="ExtendedCertificateCheck" type="{http://reference.e-government.gv.at/namespace/moa/20020822#}ExtendedCertificateCheckResultType" minOccurs="0"/&gt;
+ * &lt;/sequence&gt;
+ * &lt;/restriction&gt;
+ * &lt;/complexContent&gt;
+ * &lt;/complexType&gt;
* </pre>
*
*
*/
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "VerifyCMSSignatureResponseType", propOrder = {
- "signerInfoAndSignatureCheckAndCertificateCheck"
+ "signerInfoAndSignatureAlgorithmAndSignatureCheck"
})
public class VerifyCMSSignatureResponseType {
@XmlElementRefs({
+ @XmlElementRef(name = "SignerInfo", namespace = "http://reference.e-government.gv.at/namespace/moa/20020822#", type = JAXBElement.class),
+ @XmlElementRef(name = "SignatureAlgorithm", namespace = "http://reference.e-government.gv.at/namespace/moa/20020822#", type = JAXBElement.class),
@XmlElementRef(name = "SignatureCheck", namespace = "http://reference.e-government.gv.at/namespace/moa/20020822#", type = JAXBElement.class),
@XmlElementRef(name = "CertificateCheck", namespace = "http://reference.e-government.gv.at/namespace/moa/20020822#", type = JAXBElement.class),
- @XmlElementRef(name = "SignerInfo", namespace = "http://reference.e-government.gv.at/namespace/moa/20020822#", type = JAXBElement.class),
@XmlElementRef(name = "FormCheckResult", namespace = "http://reference.e-government.gv.at/namespace/moa/20020822#", type = JAXBElement.class),
@XmlElementRef(name = "ExtendedCertificateCheck", namespace = "http://reference.e-government.gv.at/namespace/moa/20020822#", type = JAXBElement.class)
})
- protected List<JAXBElement<?>> signerInfoAndSignatureCheckAndCertificateCheck;
+ protected List<JAXBElement<?>> signerInfoAndSignatureAlgorithmAndSignatureCheck;
/**
* Gets the value of the signerInfoAndSignatureCheckAndCertificateCheck property.
*
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the signerInfoAndSignatureCheckAndCertificateCheck property.
*
* <p>
* For example, to add a new item, do as follows:
* <pre>
- * getSignerInfoAndSignatureCheckAndCertificateCheck().add(newItem);
+ * getSignerInfoAndSignatureAlgorithmAndSignatureCheck().add(newItem);
* </pre>
*
*
* <p>
* Objects of the following type(s) are allowed in the list
- * {@link JAXBElement }{@code <}{@link KeyInfoType }{@code >}
* {@link JAXBElement }{@code <}{@link CheckResultType }{@code >}
* {@link JAXBElement }{@code <}{@link CheckResultType }{@code >}
- * {@link JAXBElement }{@code <}{@link FormResultType }{@code >}
* {@link JAXBElement }{@code <}{@link ExtendedCertificateCheckResultType }{@code >}
+ * {@link JAXBElement }{@code <}{@link FormResultType }{@code >}
+ * {@link JAXBElement }{@code <}{@link KeyInfoType }{@code >}
+ * {@link JAXBElement }{@code <}{@link String }{@code >}
*
*
*/
- public List<JAXBElement<?>> getSignerInfoAndSignatureCheckAndCertificateCheck() {
- if (signerInfoAndSignatureCheckAndCertificateCheck == null) {
- signerInfoAndSignatureCheckAndCertificateCheck = new ArrayList<JAXBElement<?>>();
+ public List<JAXBElement<?>> getSignerInfoAndSignatureAlgorithmAndSignatureCheck() {
+ if (signerInfoAndSignatureAlgorithmAndSignatureCheck == null) {
+ signerInfoAndSignatureAlgorithmAndSignatureCheck = new ArrayList<JAXBElement<?>>();
}
- return this.signerInfoAndSignatureCheckAndCertificateCheck;
+ return this.signerInfoAndSignatureAlgorithmAndSignatureCheck;
}
}
@@ -10,83 +10,86 @@ package at.gv.egiz.moasig;
/**
- * Gets the value of the signerInfoAndSignatureCheckAndCertificateCheck property.
+ * Gets the value of the signerInfoAndSignatureAlgorithmAndSignatureCheck property.
*
* <p>
@@ -10,83 +10,86 @@ package at.gv.egiz.moasig;
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
- * This is why there is not a <CODE>set</CODE> method for the signerInfoAndSignatureCheckAndCertificateCheck property.
+ * returned list will be present inside the Jakarta XML Binding object.
+ * This is why there is not a <CODE>set</CODE> method for the signerInfoAndSignatureAlgorithmAndSignatureCheck property.
*
* <p>